==> v0.6.0.zip: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/client/node/NodeClientModule.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.client.node;

import com.google.inject.AbstractModule;
import org.elasticsearch.client.AdminClient;
import org.elasticsearch.client.Client;
import org.elasticsearch.client.ClusterAdminClient;
import org.elasticsearch.client.IndicesAdminClient;

/**
 * @author kimchy (shay.banon)
 */
public class NodeClientModule extends AbstractModule {

    @Override protected void configure() {
        bind(ClusterAdminClient.class).to(NodeClusterAdminClient.class).asEagerSingleton();
        bind(IndicesAdminClient.class).to(NodeIndicesAdminClient.class).asEagerSingleton();
        bind(AdminClient.class).to(NodeAdminClient.class).asEagerSingleton();
        bind(Client.class).to(NodeClient.class).asEagerSingleton();
    }
}

==> v0.7.0.zip: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/client/node/NodeClientModule.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.client.node;

import org.elasticsearch.client.AdminClient;
import org.elasticsearch.client.Client;
import org.elasticsearch.client.ClusterAdminClient;
import org.elasticsearch.client.IndicesAdminClient;
import org.elasticsearch.util.inject.AbstractModule;

/**
 * @author kimchy (shay.banon)
 */
public class NodeClientModule extends AbstractModule {

    @Override protected void configure() {
        bind(ClusterAdminClient.class).to(NodeClusterAdminClient.class).asEagerSingleton();
        bind(IndicesAdminClient.class).to(NodeIndicesAdminClient.class).asEagerSingleton();
        bind(AdminClient.class).to(NodeAdminClient.class).asEagerSingleton();
        bind(Client.class).to(NodeClient.class).asEagerSingleton();
    }
}
